# Debugging & Logging

Tools for debugging and understanding your agents.

## Interactive Debugging

- [auto_debug.md](auto_debug.md) - Interactive debugging with `agent.auto_debug()`
- [xray.md](xray.md) - `@xray` decorator for tool inspection
- [exceptions.md](exceptions.md) - Exception handling and debugging

## Console Output

- [console.md](console.md) - Rich console formatting and output

## Logging

- [log.md](log.md) - Activity logging configuration
- [session-yaml-format.md](session-yaml-format.md) - Session YAML format specification
